"""
Vidurai Version Information

Single source of truth for the Vidurai SDK version.
"""

__version__ = "2.2.0"
__version_info__ = (2, 2, 0)

# Schema versions (for backwards compatibility)
SCHEMA_VERSION = "vidurai-events-v1"
